[Libreoffice-commits] .: accessibility/inc accessibility/source basctl/source crashrep/source cui/source embedserv/source extensions/source forms/source package/inc package/source

Fridrich Strba fridrich at kemper.freedesktop.org
Sat Feb 5 16:03:53 PST 2011


 accessibility/inc/accessibility/extended/textwindowaccessibility.hxx |    4 -
 accessibility/source/extended/textwindowaccessibility.cxx            |    2 
 basctl/source/inc/bastypes.hxx                                       |    4 -
 crashrep/source/unx/main.cxx                                         |   26 +++++-----
 crashrep/source/win32/soreport.cpp                                   |   10 +--
 cui/source/customize/cfg.cxx                                         |    6 +-
 cui/source/inc/macropg.hxx                                           |    4 -
 cui/source/inc/scriptdlg.hxx                                         |    4 -
 embedserv/source/inc/embeddoc.hxx                                    |    6 +-
 extensions/source/bibliography/framectr.cxx                          |    4 -
 extensions/source/ole/oleobjw.cxx                                    |    8 +--
 extensions/source/ole/oleobjw.hxx                                    |    6 +-
 extensions/source/ole/unoconversionutilities.hxx                     |   26 +++++-----
 extensions/source/ole/unoobjw.cxx                                    |    4 -
 extensions/source/ole/unoobjw.hxx                                    |    6 +-
 extensions/source/propctrlr/browserlistbox.hxx                       |    4 -
 extensions/source/propctrlr/eventhandler.cxx                         |    2 
 extensions/source/propctrlr/eventhandler.hxx                         |    2 
 extensions/source/propctrlr/pcrcommontypes.hxx                       |    4 -
 extensions/source/propctrlr/propcontroller.hxx                       |    8 +--
 forms/source/component/DatabaseForm.cxx                              |    2 
 forms/source/inc/InterfaceContainer.hxx                              |    4 -
 package/inc/HashMaps.hxx                                             |    8 +--
 package/source/manifest/ManifestImport.hxx                           |    2 
 package/source/xstor/ohierarchyholder.hxx                            |    4 -
 package/source/zippackage/ZipPackage.cxx                             |    2 
 package/source/zippackage/ZipPackageFolderEnumeration.hxx            |    2 
 27 files changed, 82 insertions(+), 82 deletions(-)

New commits:
commit 3ca828cc9048205d0a93a1e03ba22ea3ea8ca4f1
Author: Fridrich Å trba <fridrich.strba at bluewin.ch>
Date:   Sat Feb 5 18:49:26 2011 +0100

    move components to boost unordered containers

diff --git a/accessibility/inc/accessibility/extended/textwindowaccessibility.hxx b/accessibility/inc/accessibility/extended/textwindowaccessibility.hxx
index 3f7bd49..14e078a 100644
--- a/accessibility/inc/accessibility/extended/textwindowaccessibility.hxx
+++ b/accessibility/inc/accessibility/extended/textwindowaccessibility.hxx
@@ -59,7 +59,7 @@
 
 #include <memory>
 #include <queue>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 class TextEngine;
 class TextView;
@@ -396,7 +396,7 @@ private:
 };
 
 
-typedef ::std::hash_map< ::rtl::OUString,
+typedef ::boost::unordered_map< ::rtl::OUString,
                          ::css::beans::PropertyValue,
                          ::rtl::OUStringHash,
                          ::std::equal_to< ::rtl::OUString > > tPropValMap;
diff --git a/accessibility/source/extended/textwindowaccessibility.cxx b/accessibility/source/extended/textwindowaccessibility.cxx
index b0372e9..6bf22d4 100644
--- a/accessibility/source/extended/textwindowaccessibility.cxx
+++ b/accessibility/source/extended/textwindowaccessibility.cxx
@@ -38,7 +38,7 @@
 
 #include <algorithm>
 #include <vector>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 namespace css = ::com::sun::star;
 
diff --git a/basctl/source/inc/bastypes.hxx b/basctl/source/inc/bastypes.hxx
index 6f26ac7..f987144 100644
--- a/basctl/source/inc/bastypes.hxx
+++ b/basctl/source/inc/bastypes.hxx
@@ -51,7 +51,7 @@ class SfxItemSet;
 #include <svtools/tabbar.hxx>
 #include <com/sun/star/script/XLibraryContainer.hpp>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <vector>
 
 #define LINE_SEP_CR		0x0D
@@ -309,7 +309,7 @@ private:
         }
     };
 
-    typedef ::std::hash_map< LibInfoKey, LibInfoItem*, LibInfoKeyHash, ::std::equal_to< LibInfoKey > > LibInfoMap;
+    typedef ::boost::unordered_map< LibInfoKey, LibInfoItem*, LibInfoKeyHash, ::std::equal_to< LibInfoKey > > LibInfoMap;
     LibInfoMap  m_aLibInfoMap;
 
 public:
diff --git a/crashrep/source/unx/main.cxx b/crashrep/source/unx/main.cxx
index 8c8dfa5..876a4c2 100644
--- a/crashrep/source/unx/main.cxx
+++ b/crashrep/source/unx/main.cxx
@@ -40,7 +40,7 @@
 #include <pthread.h>
 #include <limits.h>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <vector>
 #include <string>
 
@@ -182,7 +182,7 @@ static size_t fcopy( FILE *fpout, FILE *fpin )
    from which it can be reviewed and sent
 */
 
-bool write_report( const hash_map< string, string >& rSettings )
+bool write_report( const boost::unordered_map< string, string >& rSettings )
 {
     FILE	*fp = fopen( tmpnam( g_szReportFile ), "w" );
     const char *pszUserType = getenv( "STAROFFICE_USERTYPE" );
@@ -249,7 +249,7 @@ bool write_report( const hash_map< string, string >& rSettings )
 }
 
 
-bool write_description( const hash_map< string, string >& rSettings )
+bool write_description( const boost::unordered_map< string, string >& rSettings )
 {
     bool	bSuccess = false;
     FILE	*fp = fopen( tmpnam( g_szDescriptionFile ), "w" );
@@ -267,17 +267,17 @@ bool write_description( const hash_map< string, string >& rSettings )
 
 #if 0
 // unused
-static void printSettings( const hash_map<string,string>& rSettings )
+static void printSettings( const boost::unordered_map<string,string>& rSettings )
 {
     printf( "Settings:\n" );
-    for( hash_map<string,string>::const_iterator it = rSettings.begin(); it != rSettings.end(); ++it )
+    for( boost::unordered_map<string,string>::const_iterator it = rSettings.begin(); it != rSettings.end(); ++it )
     {
         printf( "%s=\"%s\"\n", it->first.c_str(), it->second.c_str() );
     }
 }
 #endif
 
-bool save_crash_report( const string& rFileName, const hash_map< string, string >& /*rSettings*/ )
+bool save_crash_report( const string& rFileName, const boost::unordered_map< string, string >& /*rSettings*/ )
 {
     bool bSuccess = false;
     FILE	*fpout = fopen( rFileName.c_str(), "w" );
@@ -493,7 +493,7 @@ struct RequestParams
 };
 
 
-bool send_crash_report( const hash_map< string, string >& rSettings )
+bool send_crash_report( const boost::unordered_map< string, string >& rSettings )
 {
     if ( 0 == strcasecmp( rSettings.find( "CONTACT" )->second.c_str(), "true" ) &&
          !trim_string(rSettings.find( "EMAIL" )->second).length() )
@@ -557,7 +557,7 @@ static bool append_file( const char *filename, string& rString )
     return true;
 }
 
-string crash_get_details( const hash_map< string, string >& rSettings )
+string crash_get_details( const boost::unordered_map< string, string >& rSettings )
 {
     string aRet;
 
@@ -911,7 +911,7 @@ static bool write_crash_data()
 
 #if 0
 // unused
-static bool write_settings( const hash_map< string, string >& rSettings )
+static bool write_settings( const boost::unordered_map< string, string >& rSettings )
 {
     bool success = false;
     string	sRCFile = get_home_dir();
@@ -936,7 +936,7 @@ static bool write_settings( const hash_map< string, string >& rSettings )
 }
 #endif
 
-static void read_settings( hash_map< string, string >& rSettings )
+static void read_settings( boost::unordered_map< string, string >& rSettings )
 {
     string	sRCFile = get_home_dir();
 
@@ -952,7 +952,7 @@ static void read_settings( hash_map< string, string >& rSettings )
     rSettings[ "TITLE" ] = "";
 }
 
-static void read_settings_from_environment( hash_map< string, string >& rSettings )
+static void read_settings_from_environment( boost::unordered_map< string, string >& rSettings )
 {
     string	strEnv;
 
@@ -1071,7 +1071,7 @@ int main( int argc, char** argv )
 
         if ( g_bSendReport )
         {
-            hash_map< string, string > aDialogSettings;
+            boost::unordered_map< string, string > aDialogSettings;
 
             read_settings( aDialogSettings );
             read_settings_from_environment( aDialogSettings );
@@ -1080,7 +1080,7 @@ int main( int argc, char** argv )
         }
         else
         {
-            hash_map< string, string > aDialogSettings;
+            boost::unordered_map< string, string > aDialogSettings;
 
             read_settings( aDialogSettings );
             read_settings_from_environment( aDialogSettings );
diff --git a/crashrep/source/win32/soreport.cpp b/crashrep/source/win32/soreport.cpp
index a05d01a..29b8748 100644
--- a/crashrep/source/win32/soreport.cpp
+++ b/crashrep/source/win32/soreport.cpp
@@ -70,7 +70,7 @@
 #include <io.h>
 #include <fcntl.h>
 #include <string>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <winsock.h>
 #include <malloc.h>
 #include <process.h>
@@ -1700,7 +1700,7 @@ static sal_uInt32 calc_md5_checksum( const char *filename, sal_uInt8 *pChecksum,
 #endif
 //***************************************************************************
 
-static bool WriteStackFile( FILE *fout, hash_map< string, string >& rLibraries, DWORD dwProcessId, PEXCEPTION_POINTERS pExceptionPointers )
+static bool WriteStackFile( FILE *fout, boost::unordered_map< string, string >& rLibraries, DWORD dwProcessId, PEXCEPTION_POINTERS pExceptionPointers )
 {
     bool	fSuccess = false;
 
@@ -1823,7 +1823,7 @@ static bool WriteStackFile( FILE *fout, hash_map< string, string >& rLibraries,
     return fSuccess;
 }
 
-bool WriteChecksumFile( FILE *fchksum, const hash_map< string, string >& rLibraries )
+bool WriteChecksumFile( FILE *fchksum, const boost::unordered_map< string, string >& rLibraries )
 {
     bool success = false;
 
@@ -1831,7 +1831,7 @@ bool WriteChecksumFile( FILE *fchksum, const hash_map< string, string >& rLibrar
     {
         fprintf( fchksum, "<errormail:Checksums type=\"MD5\">\n" );
 
-        hash_map< string, string >::const_iterator iter;
+        boost::unordered_map< string, string >::const_iterator iter;
 
         for ( iter = rLibraries.begin(); 
             iter != rLibraries.end(); 
@@ -2883,7 +2883,7 @@ int WINAPI _tWinMain( HINSTANCE hInstance, HINSTANCE, LPTSTR /*lpCmdLine*/, int
 
         if( bGotDumpFile )
         {
-            hash_map< string, string > aLibraries;
+            boost::unordered_map< string, string > aLibraries;
 
             if ( g_bLoadReport )
             {
diff --git a/cui/source/inc/macropg.hxx b/cui/source/inc/macropg.hxx
index d257e6a..f68802b 100644
--- a/cui/source/inc/macropg.hxx
+++ b/cui/source/inc/macropg.hxx
@@ -39,10 +39,10 @@
 #include <vcl/lstbox.hxx>
 #include <rtl/ustring.hxx>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <vector>
 
-typedef ::std::hash_map< ::rtl::OUString, ::std::pair< ::rtl::OUString, ::rtl::OUString >, ::rtl::OUStringHash, ::std::equal_to< ::rtl::OUString > > EventsHash;
+typedef ::boost::unordered_map< ::rtl::OUString, ::std::pair< ::rtl::OUString, ::rtl::OUString >, ::rtl::OUStringHash, ::std::equal_to< ::rtl::OUString > > EventsHash;
 
 struct EventDisplayName
 {
diff --git a/cui/source/inc/scriptdlg.hxx b/cui/source/inc/scriptdlg.hxx
index eee80a6..ba4877c 100644
--- a/cui/source/inc/scriptdlg.hxx
+++ b/cui/source/inc/scriptdlg.hxx
@@ -44,7 +44,7 @@
 #include <com/sun/star/script/browse/XBrowseNode.hpp>
 #include <com/sun/star/frame/XModel.hpp>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 #define OBJTYPE_BASICMANAGER	1L
 #define OBJTYPE_METHOD			2L
@@ -61,7 +61,7 @@
 #define INPUTMODE_NEWMACRO		2
 #define INPUTMODE_RENAME		3
 
-typedef ::std::hash_map < ::rtl::OUString, ::rtl::OUString ,
+typedef ::boost::unordered_map < ::rtl::OUString, ::rtl::OUString ,
     ::rtl::OUStringHash, ::std::equal_to< ::rtl::OUString > > Selection_hash;
 
 class SFEntry;
diff --git a/embedserv/source/inc/embeddoc.hxx b/embedserv/source/inc/embeddoc.hxx
index 4a48456..61f2aed 100644
--- a/embedserv/source/inc/embeddoc.hxx
+++ b/embedserv/source/inc/embeddoc.hxx
@@ -39,15 +39,15 @@
 #include <oleidl.h>
 #include <objidl.h>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <com/sun/star/uno/Reference.h>
 #include <com/sun/star/uno/SEQUENCE.h>
 
 #include "embeddocaccess.hxx"
 #include "docholder.hxx"
 
-typedef ::std::hash_map< DWORD, IAdviseSink* > AdviseSinkHashMap;
-typedef ::std::hash_map< DWORD, IAdviseSink* >::iterator AdviseSinkHashMapIterator;
+typedef ::boost::unordered_map< DWORD, IAdviseSink* > AdviseSinkHashMap;
+typedef ::boost::unordered_map< DWORD, IAdviseSink* >::iterator AdviseSinkHashMapIterator;
 
 class GDIMetaFile;
 class CIIAObj;
diff --git a/extensions/source/bibliography/framectr.cxx b/extensions/source/bibliography/framectr.cxx
index 0c67601..cf0339c 100644
--- a/extensions/source/bibliography/framectr.cxx
+++ b/extensions/source/bibliography/framectr.cxx
@@ -61,7 +61,7 @@
 #include <vcl/edit.hxx>
 #include <osl/mutex.hxx>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 using namespace osl;
 using namespace cppu;
@@ -110,7 +110,7 @@ static DispatchInfo SupportedCommandsArray[] =
     { 0                         ,   0                               , sal_False }
 };
 
-typedef ::std::hash_map< ::rtl::OUString, CacheDispatchInfo, rtl::OUStringHash, ::std::equal_to< ::rtl::OUString > > CmdToInfoCache;
+typedef ::boost::unordered_map< ::rtl::OUString, CacheDispatchInfo, rtl::OUStringHash, ::std::equal_to< ::rtl::OUString > > CmdToInfoCache;
 
 SV_IMPL_PTRARR( BibStatusDispatchArr, BibStatusDispatchPtr );
 
diff --git a/extensions/source/ole/oleobjw.cxx b/extensions/source/ole/oleobjw.cxx
index 528acf4..ef17f86 100644
--- a/extensions/source/ole/oleobjw.cxx
+++ b/extensions/source/ole/oleobjw.cxx
@@ -91,16 +91,16 @@ namespace ole_adapter
 // called.
 // Before UNO object is wrapped to COM object this map is checked
 // to see if the UNO object is already a wrapper.
-hash_map<sal_uInt32, sal_uInt32> AdapterToWrapperMap;
+boost::unordered_map<sal_uInt32, sal_uInt32> AdapterToWrapperMap;
 // key: XInterface of the wrapper object.
 // value: XInterface of the Interface created by the Invocation Adapter Factory.
 // A COM wrapper is responsible for removing the corresponding entry
 // in AdapterToWrappperMap if it is being destroyed. Because the wrapper does not
 // know about its adapted interface it uses WrapperToAdapterMap to get the
 // adapted interface which is then used to locate the entry in AdapterToWrapperMap.
-hash_map<sal_uInt32,sal_uInt32> WrapperToAdapterMap;
+boost::unordered_map<sal_uInt32,sal_uInt32> WrapperToAdapterMap;
 
-hash_map<sal_uInt32, WeakReference<XInterface> > ComPtrToWrapperMap;
+boost::unordered_map<sal_uInt32, WeakReference<XInterface> > ComPtrToWrapperMap;
 /*****************************************************************************
 
     class implementation IUnknownWrapper_Impl
@@ -127,7 +127,7 @@ IUnknownWrapper_Impl::~IUnknownWrapper_Impl()
 #endif
 
     // remove entries in global maps
-    typedef hash_map<sal_uInt32, sal_uInt32>::iterator _IT;
+    typedef boost::unordered_map<sal_uInt32, sal_uInt32>::iterator _IT;
     _IT it=	WrapperToAdapterMap.find( (sal_uInt32) xIntRoot);
     if( it != WrapperToAdapterMap.end())
     {
diff --git a/extensions/source/ole/oleobjw.hxx b/extensions/source/ole/oleobjw.hxx
index 0f92669..4bba578 100644
--- a/extensions/source/ole/oleobjw.hxx
+++ b/extensions/source/ole/oleobjw.hxx
@@ -43,7 +43,7 @@
 #endif
 #include <atlbase.h>
 #include <vector>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <tools/postsys.h>
 
 #ifdef _MSC_VER
@@ -76,9 +76,9 @@ namespace ole_adapter
 
 
 
-typedef hash_map<OUString, pair<DISPID, unsigned short>, hashOUString_Impl, equalOUString_Impl> DispIdMap;
+typedef boost::unordered_map<OUString, pair<DISPID, unsigned short>, hashOUString_Impl, equalOUString_Impl> DispIdMap;
 
-typedef hash_multimap<OUString, unsigned int, hashOUString_Impl, equalOUString_Impl> TLBFuncIndexMap;
+typedef boost::unordered_multimap<OUString, unsigned int, hashOUString_Impl, equalOUString_Impl> TLBFuncIndexMap;
 
 // This class wraps an IDispatch and maps XInvocation calls to IDispatch calls on the wrapped object.
 // If m_TypeDescription is set then this class represents an UNO interface implemented in a COM component.
diff --git a/extensions/source/ole/unoconversionutilities.hxx b/extensions/source/ole/unoconversionutilities.hxx
index afca47f..328fec4 100644
--- a/extensions/source/ole/unoconversionutilities.hxx
+++ b/extensions/source/ole/unoconversionutilities.hxx
@@ -41,7 +41,7 @@
 #include "ole2uno.hxx"
 
 #include "unotypewrapper.hxx"
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 // for some reason DECIMAL_NEG (wtypes.h) which contains BYTE is not resolved.
 typedef unsigned char   BYTE;
@@ -72,17 +72,17 @@ using namespace com::sun::star::bridge::oleautomation;
 using namespace boost;
 namespace ole_adapter
 {
-extern hash_map<sal_uInt32, sal_uInt32> AdapterToWrapperMap;
-extern hash_map<sal_uInt32, sal_uInt32> WrapperToAdapterMap;
-typedef hash_map<sal_uInt32, sal_uInt32>::iterator IT_Wrap;
-typedef hash_map<sal_uInt32, sal_uInt32>::iterator CIT_Wrap;    
+extern boost::unordered_map<sal_uInt32, sal_uInt32> AdapterToWrapperMap;
+extern boost::unordered_map<sal_uInt32, sal_uInt32> WrapperToAdapterMap;
+typedef boost::unordered_map<sal_uInt32, sal_uInt32>::iterator IT_Wrap;
+typedef boost::unordered_map<sal_uInt32, sal_uInt32>::iterator CIT_Wrap;
 //Maps IUnknown pointers to a weak reference of the respective wrapper class (e.g.
 // IUnknownWrapperImpl. It is the responsibility of the wrapper to remove the entry when
 // it is being destroyed.
 // Used to ensure that an Automation object is always mapped to the same UNO objects.
-extern hash_map<sal_uInt32, WeakReference<XInterface> > ComPtrToWrapperMap;
-typedef hash_map<sal_uInt32, WeakReference<XInterface> >::iterator IT_Com;
-typedef hash_map<sal_uInt32, WeakReference<XInterface> >::const_iterator CIT_Com;    
+extern boost::unordered_map<sal_uInt32, WeakReference<XInterface> > ComPtrToWrapperMap;
+typedef boost::unordered_map<sal_uInt32, WeakReference<XInterface> >::iterator IT_Com;
+typedef boost::unordered_map<sal_uInt32, WeakReference<XInterface> >::const_iterator CIT_Com;
 
 // Maps XInterface pointers to a weak reference of its wrapper class (i.e.
 // InterfaceOleWrapper_Impl). It is the responsibility of the wrapper to remove the entry when
@@ -90,9 +90,9 @@ typedef hash_map<sal_uInt32, WeakReference<XInterface> >::const_iterator CIT_Com
 // is mapped to IDispatch which is kept alive in the COM environment. If the same
 // UNO interface is mapped again to COM then the IDispach of the first mapped instance
 // must be returned.
-extern hash_map<sal_uInt32, WeakReference<XInterface> > UnoObjToWrapperMap;
-typedef hash_map<sal_uInt32, WeakReference<XInterface> >::iterator IT_Uno;
-typedef hash_map<sal_uInt32, WeakReference<XInterface> >::const_iterator CIT_Uno;
+extern boost::unordered_map<sal_uInt32, WeakReference<XInterface> > UnoObjToWrapperMap;
+typedef boost::unordered_map<sal_uInt32, WeakReference<XInterface> >::iterator IT_Uno;
+typedef boost::unordered_map<sal_uInt32, WeakReference<XInterface> >::const_iterator CIT_Uno;
 #ifdef __MINGW32__
 inline void reduceRange( Any& any);
 #endif
@@ -1420,7 +1420,7 @@ void UnoConversionUtilities<T>::createUnoObjectWrapper(const Any & rObj, VARIANT
         else
         {
             Reference<XInterface> xIntComWrapper = xInt;
-            typedef hash_map<sal_uInt32,sal_uInt32>::iterator _IT;
+            typedef boost::unordered_map<sal_uInt32,sal_uInt32>::iterator _IT;
             // Adapter? then get the COM wrapper to which the adapter delegates its calls
             _IT it= AdapterToWrapperMap.find( (sal_uInt32) xInt.get());
             if( it != AdapterToWrapperMap.end() )
@@ -1910,7 +1910,7 @@ Reference<XInterface> UnoConversionUtilities<T>::createAdapter(const Sequence<Ty
         // in a global map. Thus we can determine in a call to createUnoObjectWrapper whether the UNO 
         // object is a wrapped COM object. In that case we extract the original COM object rather than
         // creating a wrapper around the UNO object.
-        typedef hash_map<sal_uInt32,sal_uInt32>::value_type VALUE;
+        typedef boost::unordered_map<sal_uInt32,sal_uInt32>::value_type VALUE;
         AdapterToWrapperMap.insert( VALUE( (sal_uInt32) xIntAdapted.get(), (sal_uInt32) receiver.get()));
         WrapperToAdapterMap.insert( VALUE( (sal_uInt32) receiver.get(), (sal_uInt32) xIntAdapted.get()));
     }
diff --git a/extensions/source/ole/unoobjw.cxx b/extensions/source/ole/unoobjw.cxx
index 77bfbf6..bb0aa97 100644
--- a/extensions/source/ole/unoobjw.cxx
+++ b/extensions/source/ole/unoobjw.cxx
@@ -35,7 +35,7 @@
 #include <olectl.h>
 #include <vector>
 #include <list>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <tools/postsys.h>
 
 
@@ -85,7 +85,7 @@ extern "C" const GUID IID_IDispatchEx;
 
 namespace ole_adapter
 {
-hash_map<sal_uInt32, WeakReference<XInterface> > UnoObjToWrapperMap;
+boost::unordered_map<sal_uInt32, WeakReference<XInterface> > UnoObjToWrapperMap;
 static sal_Bool writeBackOutParameter(VARIANTARG* pDest, VARIANT* pSource);
 static sal_Bool writeBackOutParameter2( VARIANTARG* pDest, VARIANT* pSource);
 static HRESULT mapCannotConvertException( CannotConvertException e, unsigned int * puArgErr);
diff --git a/extensions/source/ole/unoobjw.hxx b/extensions/source/ole/unoobjw.hxx
index 7552e44..c13250f 100644
--- a/extensions/source/ole/unoobjw.hxx
+++ b/extensions/source/ole/unoobjw.hxx
@@ -86,7 +86,7 @@ struct MemberInfo
     OUString name;
 };
 
-typedef hash_map
+typedef boost::unordered_map
 <
     OUString,
     DISPID,
@@ -94,7 +94,7 @@ typedef hash_map
     equalOUString_Impl
 > NameToIdMap;
 
-typedef hash_map
+typedef boost::unordered_map
 <
     OUString,
     sal_Bool,
@@ -102,7 +102,7 @@ typedef hash_map
     equalOUString_Impl
 > BadNameMap;
 
-typedef hash_map
+typedef boost::unordered_map
 <
     DISPID,
     MemberInfo
diff --git a/extensions/source/propctrlr/browserlistbox.hxx b/extensions/source/propctrlr/browserlistbox.hxx
index 6ae8b64..36a471f 100644
--- a/extensions/source/propctrlr/browserlistbox.hxx
+++ b/extensions/source/propctrlr/browserlistbox.hxx
@@ -45,7 +45,7 @@
 
 #include <set>
 #include <vector>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <boost/shared_ptr.hpp>
 
 //............................................................................
@@ -76,7 +76,7 @@ namespace pcr
         {
         }
     };
-    typedef ::std::hash_map< ::rtl::OUString, ListBoxLine, ::rtl::OUStringHash >    ListBoxLines;
+    typedef ::boost::unordered_map< ::rtl::OUString, ListBoxLine, ::rtl::OUStringHash >    ListBoxLines;
     typedef ::std::vector< ListBoxLines::iterator >                                 OrderedListBoxLines;
 
     //========================================================================
diff --git a/extensions/source/propctrlr/eventhandler.cxx b/extensions/source/propctrlr/eventhandler.cxx
index dc38400..956ff8f 100644
--- a/extensions/source/propctrlr/eventhandler.cxx
+++ b/extensions/source/propctrlr/eventhandler.cxx
@@ -354,7 +354,7 @@ namespace pcr
     class EventHolder : public EventHolder_Base
     {
     private:
-        typedef ::std::hash_map< ::rtl::OUString, ScriptEventDescriptor, ::rtl::OUStringHash >  EventMap;
+        typedef ::boost::unordered_map< ::rtl::OUString, ScriptEventDescriptor, ::rtl::OUStringHash >  EventMap;
         typedef ::std::map< EventId, EventMap::iterator >                                       EventMapIndexAccess;
 
         EventMap            m_aEventNameAccess;
diff --git a/extensions/source/propctrlr/eventhandler.hxx b/extensions/source/propctrlr/eventhandler.hxx
index 7e113ec..914f8b9 100644
--- a/extensions/source/propctrlr/eventhandler.hxx
+++ b/extensions/source/propctrlr/eventhandler.hxx
@@ -79,7 +79,7 @@ namespace pcr
             sal_Int32 _nUniqueBrowseId );
     };
 
-    typedef ::std::hash_map< ::rtl::OUString, EventDescription, ::rtl::OUStringHash >   EventMap;
+    typedef ::boost::unordered_map< ::rtl::OUString, EventDescription, ::rtl::OUStringHash >   EventMap;
 
     //====================================================================
     //= EventHandler
diff --git a/extensions/source/propctrlr/pcrcommontypes.hxx b/extensions/source/propctrlr/pcrcommontypes.hxx
index 0c20bf3..28c18ee 100644
--- a/extensions/source/propctrlr/pcrcommontypes.hxx
+++ b/extensions/source/propctrlr/pcrcommontypes.hxx
@@ -34,14 +34,14 @@
 /** === end UNO includes === **/
 #include <rtl/ustring.hxx>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 //........................................................................
 namespace pcr
 {
 //........................................................................
 
-    typedef ::std::hash_map< ::rtl::OUString, ::com::sun::star::beans::Property, ::rtl::OUStringHash >
+    typedef ::boost::unordered_map< ::rtl::OUString, ::com::sun::star::beans::Property, ::rtl::OUStringHash >
         PropertyMap;
 
 //........................................................................
diff --git a/extensions/source/propctrlr/propcontroller.hxx b/extensions/source/propctrlr/propcontroller.hxx
index 154914e..8e768f0 100644
--- a/extensions/source/propctrlr/propcontroller.hxx
+++ b/extensions/source/propctrlr/propcontroller.hxx
@@ -68,7 +68,7 @@
 #include <comphelper/broadcasthelper.hxx>
 
 #include <map>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <vector>
 #include <memory>
 
@@ -137,9 +137,9 @@ namespace pcr
         typedef ::com::sun::star::uno::Reference< ::com::sun::star::inspection::XPropertyHandler >
                                                         PropertyHandlerRef;
         typedef ::std::vector< PropertyHandlerRef >     PropertyHandlerArray;
-        typedef ::std::hash_map< ::rtl::OUString, PropertyHandlerRef, ::rtl::OUStringHash >
+        typedef ::boost::unordered_map< ::rtl::OUString, PropertyHandlerRef, ::rtl::OUStringHash >
                                                         PropertyHandlerRepository;
-        typedef ::std::hash_multimap< ::rtl::OUString, PropertyHandlerRef, ::rtl::OUStringHash >
+        typedef ::boost::unordered_multimap< ::rtl::OUString, PropertyHandlerRef, ::rtl::OUStringHash >
                                                         PropertyHandlerMultiRepository;
         PropertyHandlerRepository                       m_aPropertyHandlers;
         PropertyHandlerMultiRepository                  m_aDependencyHandlers;
@@ -157,7 +157,7 @@ namespace pcr
         /// the property we're just committing
         ::rtl::OUString                                 m_sCommittingProperty;
 
-        typedef ::std::hash_map< ::rtl::OUString, sal_uInt16, ::rtl::OUStringHash >     HashString2Int16;
+        typedef ::boost::unordered_map< ::rtl::OUString, sal_uInt16, ::rtl::OUStringHash >     HashString2Int16;
         HashString2Int16                                m_aPageIds;
 
         bool        m_bContainerFocusListening;
diff --git a/forms/source/component/DatabaseForm.cxx b/forms/source/component/DatabaseForm.cxx
index a77c9b4..13cf47b 100644
--- a/forms/source/component/DatabaseForm.cxx
+++ b/forms/source/component/DatabaseForm.cxx
@@ -92,7 +92,7 @@
 #include <osl/mutex.hxx>
 
 #include <ctype.h>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 // compatiblity: DatabaseCursorType is dead, but for compatiblity reasons we still have to write it ...
 namespace com {
diff --git a/forms/source/inc/InterfaceContainer.hxx b/forms/source/inc/InterfaceContainer.hxx
index 0f03139..a6a862d 100644
--- a/forms/source/inc/InterfaceContainer.hxx
+++ b/forms/source/inc/InterfaceContainer.hxx
@@ -29,7 +29,7 @@
 #ifndef _FRM_INTERFACE_CONTAINER_HXX_
 #define _FRM_INTERFACE_CONTAINER_HXX_
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <comphelper/stl_types.hxx>
 #include <comphelper/types.hxx>
 #include <comphelper/uno3.hxx>
@@ -83,7 +83,7 @@ namespace frm
     };
 
 typedef ::std::vector<InterfaceRef> OInterfaceArray;
-typedef ::std::hash_multimap< ::rtl::OUString, InterfaceRef, ::comphelper::UStringHash, ::comphelper::UStringEqual> OInterfaceMap;
+typedef ::boost::unordered_multimap< ::rtl::OUString, InterfaceRef, ::comphelper::UStringHash, ::comphelper::UStringEqual> OInterfaceMap;
 
 //==================================================================
 // OInterfaceContainer
diff --git a/package/inc/HashMaps.hxx b/package/inc/HashMaps.hxx
index 637f56a..5ec543e 100644
--- a/package/inc/HashMaps.hxx
+++ b/package/inc/HashMaps.hxx
@@ -30,7 +30,7 @@
 
 #include <ZipEntry.hxx>
 #include <rtl/ref.hxx>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 struct eqFunc
 {
@@ -46,17 +46,17 @@ namespace com { namespace sun { namespace star { namespace packages {
 class ContentInfo;
 } } } }
 
-typedef std::hash_map < rtl::OUString, 
+typedef boost::unordered_map < rtl::OUString, 
                         ZipPackageFolder *,
                         ::rtl::OUStringHash, 
                         eqFunc > FolderHash;
 
-typedef std::hash_map < rtl::OUString, 
+typedef boost::unordered_map < rtl::OUString, 
                         rtl::Reference < com::sun::star::packages::ContentInfo >,
                         ::rtl::OUStringHash, 
                         eqFunc > ContentHash;
 
-typedef std::hash_map < rtl::OUString, 
+typedef boost::unordered_map < rtl::OUString, 
                         ZipEntry, 
                         rtl::OUStringHash, 
                         eqFunc > EntryHash;
diff --git a/package/source/manifest/ManifestImport.hxx b/package/source/manifest/ManifestImport.hxx
index 6a48672..9655e71 100644
--- a/package/source/manifest/ManifestImport.hxx
+++ b/package/source/manifest/ManifestImport.hxx
@@ -40,7 +40,7 @@ namespace com { namespace sun { namespace star {
     namespace beans { struct PropertyValue; }
 } } }
 
-typedef ::std::hash_map< ::rtl::OUString, ::rtl::OUString, ::rtl::OUStringHash, eqFunc > StringHashMap;
+typedef ::boost::unordered_map< ::rtl::OUString, ::rtl::OUString, ::rtl::OUStringHash, eqFunc > StringHashMap;
 
 struct ManifestScopeEntry
 {
diff --git a/package/source/xstor/ohierarchyholder.hxx b/package/source/xstor/ohierarchyholder.hxx
index 6fff34c..1b54497 100644
--- a/package/source/xstor/ohierarchyholder.hxx
+++ b/package/source/xstor/ohierarchyholder.hxx
@@ -36,7 +36,7 @@
 
 #include <rtl/ref.hxx>
 
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 #include <list>
 #include <vector>
 
@@ -50,7 +50,7 @@ struct eqFunc
         return r1 == r2;
     }
 };
-typedef ::std::hash_map< ::rtl::OUString,
+typedef ::boost::unordered_map< ::rtl::OUString,
                          ::rtl::Reference< OHierarchyElement_Impl >,
                          ::rtl::OUStringHash,
                          eqFunc > OHierarchyElementList_Impl;
diff --git a/package/source/zippackage/ZipPackage.cxx b/package/source/zippackage/ZipPackage.cxx
index 5e2b00c..39ddc80 100644
--- a/package/source/zippackage/ZipPackage.cxx
+++ b/package/source/zippackage/ZipPackage.cxx
@@ -208,7 +208,7 @@ ZipPackage::~ZipPackage( void )
 #if 0
     // As all folders and streams contain references to their parents,
     // we must remove these references so that they will be deleted when
-    // the hash_map of the root folder is cleared, releasing all subfolders
+    // the boost::unordered_map of the root folder is cleared, releasing all subfolders
     // and substreams which in turn release theirs, etc. When m_xRootFolder is
     // released when this destructor completes, the folder tree should be
     // deleted fully (and automagically).
diff --git a/package/source/zippackage/ZipPackageFolderEnumeration.hxx b/package/source/zippackage/ZipPackageFolderEnumeration.hxx
index 751ffbf..58e4324 100644
--- a/package/source/zippackage/ZipPackageFolderEnumeration.hxx
+++ b/package/source/zippackage/ZipPackageFolderEnumeration.hxx
@@ -43,7 +43,7 @@ protected:
     ContentHash& rContents;
     ContentHash::const_iterator aIterator;
 public:
-    //ZipPackageFolderEnumeration (std::hash_map < rtl::OUString, com::sun::star::uno::Reference < com::sun::star::container::XNamed >, hashFunc, eqFunc > &rInput);
+    //ZipPackageFolderEnumeration (boost::unordered_map < rtl::OUString, com::sun::star::uno::Reference < com::sun::star::container::XNamed >, hashFunc, eqFunc > &rInput);
     ZipPackageFolderEnumeration (ContentHash &rInput);
     virtual ~ZipPackageFolderEnumeration( void );
 


More information about the Libreoffice-commits mailing list
diff --git a/cui/source/customize/cfg.cxx b/cui/source/customize/cfg.cxx
index 5bfb108..4c0aa05 100644
--- a/cui/source/customize/cfg.cxx
+++ b/cui/source/customize/cfg.cxx
@@ -4141,7 +4141,7 @@ bool EntrySort( SvxConfigEntry* a, SvxConfigEntry* b )
 
 SvxEntries*	ToolbarSaveInData::GetEntries()
 {
-    typedef ::std::hash_map< ::rtl::OUString,
+    typedef ::boost::unordered_map< ::rtl::OUString,
                              bool,
                              ::rtl::OUStringHash,
                              ::std::equal_to< ::rtl::OUString > > ToolbarInfo;
@@ -4202,7 +4202,7 @@ SvxEntries*	ToolbarSaveInData::GetEntries()
                 pEntry->SetStyle( GetSystemStyle( url ) );
 
 
                 // insert into hash_map to filter duplicates from the parent
                 aToolbarInfo.insert( ToolbarInfo::value_type( systemname, true ));
 
                 OUString custom(RTL_CONSTASCII_USTRINGPARAM(CUSTOM_TOOLBAR_STR));
@@ -5290,7 +5290,7 @@ SvxIconSelectorDialog::SvxIconSelectorDialog( Window *pWindow,
 {
     FreeResource();
 
-    typedef ::std::hash_map< ::rtl::OUString,
+    typedef ::boost::unordered_map< ::rtl::OUString,
                              bool,
                              ::rtl::OUStringHash,
                              ::std::equal_to< ::rtl::OUString > > ImageInfo;
@@ -4202,7 +4202,7 @@ SvxEntries*	ToolbarSaveInData::GetEntries()
 
 
-                // insert into hash_map to filter duplicates from the parent
+                // insert into boost::unordered_map to filter duplicates from the parent
                 aToolbarInfo.insert( ToolbarInfo::value_type( systemname, true ));
 